@@ -1,5 +1,5 @@
 /* strerror-tld.c --- Convert TLD errors into text.
- * Copyright (C) 2004  Simon Josefsson
+ * Copyright (C) 2004, 2005, 2006, 2007  Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -15,10 +15,14 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "tld.h"
 
 #include "gettext.h"
